function [fig_out, axes_out, plot_out] = da(w,varargin)
%--------help for gtk area plot da command---------------------------------
%
% Area plot of dataset_2d (or array of dataset_1d)
%
% Function Syntax: 
% [figureHandle_,axesHandle_,plotHandle_] = 
% DA(w,[property_name,property_value]) or
% DA(w,xlo,xhi) or
% DA(w,xlo,xhi,ylo,yhi)
%
% Output: figure,axes and plot handle
% Input: 2d dataset object and other control parameters (name value pairs)
% list of control propertie names:
%
% >>IXG_ST_DEFAULT.figure
% >>IXG_ST_DEFAULT.plot
% >>IXG_ST_DEFAULT.axes
% you can also give axis limit for x, y and z
%
% Purpose: plot the data according to values and control properties (for
% figure, axes and plot)
%
% Example: 
% DA(w) --> default structure plot
% DA(w,'Color','red') --> override default structure values 
% DA(w,'default','my_struct','Color','red') --> override values 
% DA(w,'default','my_struct') --> from structure
% DA(w,10,20)
% DA(w,10,20,0,200)
%-------------------updated 15/08/2006, Dean Whittaker---------------------
%total
tot = numel(varargin);


if strcmp(class(w),'IXTdataset_1d')
    w=ixf_oned_to_twod(w);
end


if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area',varargin{:});
    end    
elseif (tot==6)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4})&& isnumeric(varargin{5}) && isnumeric(varargin{6}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}],'clim',[varargin{5},varargin{6}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area',varargin{:});
    end
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plot_twod(w,'area',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end
