function [fig_out, axes_out, plot_out] = dl(w,varargin)
%--------help for gtk line plot command dl --------------------------------
% Function Syntax: 
% [figureHandle_,axesHandle_,plotHandle_] = 
% DL(w,[property_name,property_value]) or
% DL(w,xlo,xhi) or
% DL(w,xlo,xhi,ylo,yhi)
%
% Output: figure,axes and plot handle
% Input: 1d dataset object and other control parameters (name value pairs)
%
% you can also give axis limit for x and y 
% Purpose: plot the data according to values and control properties (for
% figure, axes and plot)
%
% Example: 
% DL(w) --> default structure plot
% DL(w,'Color','red') --> override default structure values 
% DL(w,'default','my_struct','Color','red') --> override values 
% DL(w,'default','my_struct') --> from structure
% DL(w,10,20)
% DL(w,10,20,0,200)
%--------------------------------------------------------------------------

%total


if isa(w,'IXTdataset_2d')
    w=ixf_twod_to_oned(w);
end


tot = numel(varargin);
if ( tot == 2)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'l','xlim',[varargin{1},varargin{2}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'l',varargin{:});
    end
elseif (tot == 4)
    if (isnumeric(varargin{1}) && isnumeric(varargin{2}) && isnumeric(varargin{3}) && isnumeric(varargin{4}))
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'l','xlim',[varargin{1},varargin{2}],'ylim',[varargin{3},varargin{4}]);
    else
        [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'l',varargin{:});
    end    
else
    [figureHandle_,axesHandle_,plotHandle_] = uib_plotgeneral(w,'l',varargin{:});    
end

if nargout > 0
    fig_out = figureHandle_;
    axes_out = axesHandle_;
    plot_out = plotHandle_;
end


